@@ -39,7 +39,7 @@ six = __import__("six")
 # SOFTWARE.
 
 
-directives_core = Directives(r'/\*', r'\*/')
+directives_core = Directives(r"/\*", r"\*/")
 
 whitespaceChar = re.compile(r"\s")
 whitespacePattern = re.compile(r"(?:\s|\n)+")
@@ -57,31 +57,34 @@ def beautify(string, opts=default_options()):
 
 
 def beautify_file(file_name, opts=default_options()):
-    if file_name == '-':  # stdin
+    if file_name == "-":  # stdin
         stream = sys.stdin
     else:
         stream = open(file_name)
-    content = ''.join(stream.readlines())
+    content = "".join(stream.readlines())
     b = Beautifier(content, opts)
     return b.beautify()
 
 
 def usage(stream=sys.stdout):
 
-    print("cssbeautifier.py@" + __version__ + """
+    print(
+        "cssbeautifier.py@"
+        + __version__
+        + """
 
 CSS beautifier (https://beautifier.io/)
 
-""", file=stream)
+""",
+        file=stream,
+    )
     if stream == sys.stderr:
         return 1
     else:
         return 0
 
 
-
 class Beautifier:
-
     def __init__(self, source_text, opts=default_options()):
         # in javascript, these two differ
         # in python they are the same, different methods are called on them
@@ -89,13 +92,11 @@ class Beautifier:
         self.lineBreak = re.compile(six.u(r"\r\n|[\n\r]"))
         self.allLineBreaks = self.lineBreak
 
-        self.comment_pattern = re.compile(
-            six.u(r"\/\/(?:[^\n\r\u2028\u2029]*)"))
-        self.block_comment_pattern = re.compile(
-            r"\/\*(?:[\s\S]*?)((?:\*\/)|$)")
+        self.comment_pattern = re.compile(six.u(r"\/\/(?:[^\n\r\u2028\u2029]*)"))
+        self.block_comment_pattern = re.compile(r"\/\*(?:[\s\S]*?)((?:\*\/)|$)")
 
         if not source_text:
-            source_text = ''
+            source_text = ""
 
         self.__source_text = source_text
 
@@ -115,14 +116,12 @@ class Beautifier:
             "@keyframes",
             "@media",
             "@supports",
-            "@document"}
-        self.CONDITIONAL_GROUP_RULE = {
-            "@media",
-            "@supports",
-            "@document"}
+            "@document",
+        }
+        self.CONDITIONAL_GROUP_RULE = {"@media", "@supports", "@document"}
 
     def eatString(self, endChars):
-        result = ''
+        result = ""
         self._ch = self._input.next()
         while self._ch:
             result += self._ch
@@ -138,10 +137,10 @@ class Beautifier:
     # newline character found; if the user has preserve_newlines off, only
     # the first newline will be output
     def eatWhitespace(self, allowAtLeastOneNewLine=False):
-        result = whitespaceChar.search(self._input.peek() or '') is not None
+        result = whitespaceChar.search(self._input.peek() or "") is not None
         isFirstNewLine = True
 
-        while whitespaceChar.search(self._input.peek() or '') is not None:
+        while whitespaceChar.search(self._input.peek() or "") is not None:
             self._ch = self._input.next()
             if allowAtLeastOneNewLine and self._ch == "\n":
                 if self._options.preserve_newlines or isFirstNewLine:
@@ -173,7 +172,6 @@ class Beautifier:
 
         return False
 
-
     def indent(self):
         self._indentLevel += 1
 
@@ -190,22 +188,20 @@ class Beautifier:
         self._output.non_breaking_space = True
         self._output.add_token(output_string)
 
-
     def beautify(self):
         if self._options.disabled:
             return self.__source_text
 
         source_text = self.__source_text
 
-        if self._options.eol == 'auto':
-            self._options.eol = '\n'
-            if self.lineBreak.search(source_text or ''):
+        if self._options.eol == "auto":
+            self._options.eol = "\n"
+            if self.lineBreak.search(source_text or ""):
                 self._options.eol = self.lineBreak.search(source_text).group()
 
-
         # HACK: newline parsing inconsistent. This brute force normalizes the
         # input newlines.
-        source_text = re.sub(self.allLineBreaks, '\n', source_text)
+        source_text = re.sub(self.allLineBreaks, "\n", source_text)
         baseIndentString = re.search("^[\t ]*", source_text).group(0)
 
         self._output = Output(self._options, baseIndentString)
@@ -227,16 +223,16 @@ class Beautifier:
 
         while True:
             whitespace = self._input.read(whitespacePattern)
-            isAfterSpace = whitespace != ''
+            isAfterSpace = whitespace != ""
             previous_ch = topCharacter
             self._ch = self._input.next()
-            if self._ch == '\\' and self._input.hasNext():
+            if self._ch == "\\" and self._input.hasNext():
                 self._ch += self._input.next()
             topCharacter = self._ch
 
             if not self._ch:
                 break
-            elif self._ch == '/' and self._input.peek() == '*':
+            elif self._ch == "/" and self._input.peek() == "*":
                 # /* css comment */
                 # Always start block comments on a new line.
                 # This handles scenarios where a block comment immediately
@@ -248,7 +244,7 @@ class Beautifier:
 
                 # handle ignore directive
                 directives = directives_core.get_directives(comment)
-                if directives and directives.get('ignore') == 'start':
+                if directives and directives.get("ignore") == "start":
                     comment += directives_core.readIgnored(self._input)
 
                 self.print_string(comment)
@@ -259,7 +255,7 @@ class Beautifier:
                 # Block comments are followed by a new line so they don't
                 # share a line with other properties
                 self._output.add_new_line()
-            elif self._ch == '/' and self._input.peek() == '/':
+            elif self._ch == "/" and self._input.peek() == "/":
                 # // single line comment
                 # Preserves the space before a comment
                 # on the same line as a rule
@@ -269,17 +265,18 @@ class Beautifier:
 
                 # Ensures any new lines following the comment are preserved
                 self.eatWhitespace(True)
-            elif self._ch == '@':
+            elif self._ch == "@":
                 self.preserveSingleSpace(isAfterSpace)
 
                 # deal with less propery mixins @{...}
-                if self._input.peek() == '{':
-                    self.print_string(self._ch + self.eatString('}'))
+                if self._input.peek() == "{":
+                    self.print_string(self._ch + self.eatString("}"))
                 else:
                     self.print_string(self._ch)
                     # strip trailing space, for hash property check
                     variableOrRule = self._input.peekUntilAfter(
-                        re.compile(r"[: ,;{}()[\]\/='\"]"))
+                        re.compile(r"[: ,;{}()[\]\/='\"]")
+                    )
 
                     if variableOrRule[-1] in ": ":
                         # wwe have a variable or pseudo-class, add it and
@@ -303,41 +300,55 @@ class Beautifier:
                         self._nestedLevel += 1
                         if variableOrRule in self.CONDITIONAL_GROUP_RULE:
                             enteringConditionalGroup = True
-                    elif not insideRule and parenLevel == 0 and \
-                            variableOrRule[-1] == ":":
+                    elif (
+                        not insideRule and parenLevel == 0 and variableOrRule[-1] == ":"
+                    ):
                         insidePropertyValue = True
                         self.indent()
-            elif self._ch == '#' and self._input.peek() == '{':
+            elif self._ch == "#" and self._input.peek() == "{":
                 self.preserveSingleSpace(isAfterSpace)
-                self.print_string(self._ch + self.eatString('}'))
-            elif self._ch == '{':
+                self.print_string(self._ch + self.eatString("}"))
+            elif self._ch == "{":
                 if insidePropertyValue:
                     insidePropertyValue = False
                     self.outdent()
-                self.indent()
-                self._output.space_before_token = True
-                self.print_string(self._ch)
 
                 # when entering conditional groups, only rulesets are
                 # allowed
                 if enteringConditionalGroup:
                     enteringConditionalGroup = False
-                    insideRule = self._indentLevel > self._nestedLevel
+                    insideRule = self._indentLevel >= self._nestedLevel
                 else:
                     # otherwise, declarations are also allowed
-                    insideRule = self._indentLevel >= self._nestedLevel
+                    insideRule = self._indentLevel >= self._nestedLevel - 1
 
                 if self._options.newline_between_rules and insideRule:
-                    if self._output.previous_line and \
-                            not self._output.previous_line.is_empty() and \
-                            self._output.previous_line.item(-1) != '{':
-                        self._output.ensure_empty_line_above('/', ',')
+                    if (
+                        self._output.previous_line
+                        and not self._output.previous_line.is_empty()
+                        and self._output.previous_line.item(-1) != "{"
+                    ):
+                        self._output.ensure_empty_line_above("/", ",")
+
+                self._output.space_before_token = True
+
+                # The difference in print_string and indent order
+                # is necessary to indent the '{' correctly
+                if self._options.brace_style == "expand":
+                    self._output.add_new_line()
+                    self.print_string(self._ch)
+                    self.indent()
+                    self._output.set_indent(self._indentLevel)
+                else:
+                    self.indent()
+                    self.print_string(self._ch)
+
                 self.eatWhitespace(True)
                 self._output.add_new_line()
-            elif self._ch == '}':
+            elif self._ch == "}":
                 self.outdent()
                 self._output.add_new_line()
-                if previous_ch == '{':
+                if previous_ch == "{":
                     self._output.trim(True)
                 insideAtExtend = False
                 insideAtImport = False
@@ -352,16 +363,20 @@ class Beautifier:
                 self.eatWhitespace(True)
                 self._output.add_new_line()
 
-                if self._options.newline_between_rules and \
-                        not self._output.just_added_blankline():
-                    if self._input.peek() != '}':
+                if (
+                    self._options.newline_between_rules
+                    and not self._output.just_added_blankline()
+                ):
+                    if self._input.peek() != "}":
                         self._output.add_new_line(True)
             elif self._ch == ":":
-                if (insideRule or enteringConditionalGroup) and \
-                        not (self._input.lookBack('&') or
-                             self.foundNestedPseudoClass()) and \
-                        not self._input.lookBack('(') and not insideAtExtend and \
-                        parenLevel == 0:
+                if (
+                    (insideRule or enteringConditionalGroup)
+                    and not (self._input.lookBack("&") or self.foundNestedPseudoClass())
+                    and not self._input.lookBack("(")
+                    and not insideAtExtend
+                    and parenLevel == 0
+                ):
                     # 'property: value' delimiter
                     # which could be in a conditional group query
                     self.print_string(":")
@@ -377,7 +392,7 @@ class Beautifier:
 
                     # preserve space before pseudoclasses/pseudoelements,
                     # as it means "in any child"
-                    if self._input.lookBack(' '):
+                    if self._input.lookBack(" "):
                         self._output.space_before_token = True
                     if self._input.peek() == ":":
                         # pseudo-element
@@ -386,11 +401,11 @@ class Beautifier:
                     else:
                         # pseudo-element
                         self.print_string(":")
-            elif self._ch == '"' or self._ch == '\'':
+            elif self._ch == '"' or self._ch == "'":
                 self.preserveSingleSpace(isAfterSpace)
                 self.print_string(self._ch + self.eatString(self._ch))
                 self.eatWhitespace(True)
-            elif self._ch == ';':
+            elif self._ch == ";":
                 if parenLevel == 0:
                     if insidePropertyValue:
                         self.outdent()
@@ -404,13 +419,13 @@ class Beautifier:
                     # line. Block comments are also affected, but
                     # a new line is always output before one inside
                     # that section
-                    if self._input.peek() is not '/':
+                    if self._input.peek() is not "/":
                         self._output.add_new_line()
                 else:
                     self.print_string(self._ch)
                     self.eatWhitespace(True)
                     self._output.space_before_token = True
-            elif self._ch == '(':
+            elif self._ch == "(":
                 # may be a url
                 if self._input.lookBack("url"):
                     self.print_string(self._ch)
@@ -418,10 +433,10 @@ class Beautifier:
                     parenLevel += 1
                     self.indent()
                     self._ch = self._input.next()
-                    if self._ch in {')', '"', '\''}:
+                    if self._ch in {")", '"', "'"}:
                         self._input.back()
                     elif self._ch is not None:
-                        self.print_string(self._ch + self.eatString(')'))
+                        self.print_string(self._ch + self.eatString(")"))
                         if parenLevel:
                             parenLevel -= 1
                             self.outdent()
@@ -431,22 +446,28 @@ class Beautifier:
                     self.eatWhitespace()
                     parenLevel += 1
                     self.indent()
-            elif self._ch == ')':
+            elif self._ch == ")":
                 if parenLevel:
                     parenLevel -= 1
                     self.outdent()
                 self.print_string(self._ch)
-            elif self._ch == ',':
+            elif self._ch == ",":
                 self.print_string(self._ch)
                 self.eatWhitespace(True)
-                if self._options.selector_separator_newline and \
-                        not insidePropertyValue and parenLevel == 0 and \
-                        not insideAtImport:
+                if (
+                    self._options.selector_separator_newline
+                    and not insidePropertyValue
+                    and parenLevel == 0
+                    and not insideAtImport
+                ):
                     self._output.add_new_line()
                 else:
                     self._output.space_before_token = True
-            elif (self._ch == '>' or self._ch == '+' or self._ch == '~') and \
-                    not insidePropertyValue and parenLevel == 0:
+            elif (
+                (self._ch == ">" or self._ch == "+" or self._ch == "~")
+                and not insidePropertyValue
+                and parenLevel == 0
+            ):
                 # handle combinator spacing
                 if self._options.space_around_combinator:
                     self._output.space_before_token = True
@@ -457,21 +478,21 @@ class Beautifier:
                     self.eatWhitespace()
                     # squash extra whitespace
                     if self._ch and bool(whitespaceChar.search(self._ch)):
-                        self._ch = ''
-            elif self._ch == ']':
+                        self._ch = ""
+            elif self._ch == "]":
                 self.print_string(self._ch)
-            elif self._ch == '[':
+            elif self._ch == "[":
                 self.preserveSingleSpace(isAfterSpace)
                 self.print_string(self._ch)
-            elif self._ch == '=':
+            elif self._ch == "=":
                 # no whitespace before or after
                 self.eatWhitespace()
-                self.print_string('=')
+                self.print_string("=")
                 if bool(whitespaceChar.search(self._ch)):
-                    self._ch = ''
-            elif self._ch == '!' and not (self._input.lookBack('\\')):
+                    self._ch = ""
+            elif self._ch == "!" and not (self._input.lookBack("\\")):
                 # !important
-                self.print_string(' ')
+                self.print_string(" ")
                 self.print_string(self._ch)
             else:
                 self.preserveSingleSpace(isAfterSpace)
